summaryrefslogtreecommitdiff
path: root/libavformat/rtp.h
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat/rtp.h')
-rw-r--r--libavformat/rtp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libavformat/rtp.h b/libavformat/rtp.h
index feaf167965..01b83dfa23 100644
--- a/libavformat/rtp.h
+++ b/libavformat/rtp.h
@@ -32,11 +32,11 @@
* The format context private option payload_type overrides both.
*
* @param fmt The context of the format
* @param codec The context of the codec
* @param idx The stream index
* @return The payload type (the 'PT' field in the RTP header).
*/
-int ff_rtp_get_payload_type(AVFormatContext *fmt, AVCodecContext *codec,
+int ff_rtp_get_payload_type(AVFormatContext *fmt, AVCodecParameters *par,
int idx);
/**
@@ -46,12 +46,12 @@ int ff_rtp_get_payload_type(AVFormatContext *fmt, AVCodecContext *codec,
* information depending on the payload type; for audio codecs, the
* channels and sample_rate fields are also filled.
*
* @param codec The context of the codec
* @param payload_type The payload type (the 'PT' field in the RTP header)
* @return In case of unknown payload type or dynamic payload type, a
* negative value is returned; otherwise, 0 is returned
*/
-int ff_rtp_get_codec_info(AVCodecContext *codec, int payload_type);
+int ff_rtp_get_codec_info(AVCodecParameters *par, int payload_type);
/**
* Return the encoding name (as defined in
@@ -32,11 +32,11 @@
*
* @param fmt The context of the format
- * @param codec The context of the codec
+ * @param par The codec parameters
* @param idx The stream index
* @return The payload type (the 'PT' field in the RTP header).
@@ -46,12 +46,12 @@ int ff_rtp_get_payload_type(AVFormatContext *fmt, AVCodecContext *codec,
* channels and sample_rate fields are also filled.
*
- * @param codec The context of the codec
+ * @param par The codec parameters
* @param payload_type The payload type (the 'PT' field in the RTP header)
* @return In case of unknown payload type or dynamic payload type, a